@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.20.1+1" },
-            { "jdk", "11.0.20.1" },
-            { "release", "11.0.20.1" },
+            { "full", "17.0.4+8" },
+            { "jdk", "17.0.4" },
+            { "release", "17.0.4" },
         };
     }
 }
